/**
 * Test case for define.
 * Runs with mocha.
 */
'use strict'

const define = require('../lib/define.js')
const injectmock = require('injectmock')
const writeout = require('writeout')
const hostile = require('hostile')
const assert = require('assert')
const co = require('co')

describe('define', () => {
  let tmpHosts = `${__dirname}/../tmp/testing-hosts`

  function noop () {
  }

  before(() => co(function * () {
    yield writeout(tmpHosts, '', { mkdirp: true })
  }))
  before(() => co(function * () {
    injectmock(hostile, 'HOSTS', tmpHosts)
  }))

  after(() => co(function * () {
    injectmock.restoreAll()
  }))

  it('Define add task.', () => co(function * () {
    let task = define({
      'hoge.example.com': '192.168.1.92',
      'fuge.example.com': '192.168.1.92'
    })
    assert.ok(task)
    let context = {
      verbose: false,
      logger: {
        info: noop,
        debug: console.log,
        trace: noop
      }
    }
    task(context)
  }))

  it('Define remove task.', () => co(function * () {
    let task = define({
      'fuge.example.com': '192.168.1.92'
    }, { remove: true })
    assert.ok(task)
    let context = {
      verbose: false,
      logger: {
        info: noop,
        debug: console.log,
        trace: noop
      }
    }
    task(context)
  }))

  it('Define list task.', () => co(function * () {
    let task = define({ list: true })
    assert.ok(task)
    let context = {
      verbose: false,
      logger: {
        info: noop,
        debug: console.log,
        trace: noop
      }
    }
    yield task(context)
  }))
})

/* global describe, before, after, it */
